PushNotificationProvider class abstract

Mixed-in types

Constructors

PushNotificationProvider()

Properties

apnsToken Future<String?>
no setter
hashCode int
The hash code for this object.
no setterinherited
initialNotification Future<NotificationData?>
no setterinherited
onNotification Stream<NotificationData>
no setterinherited
onNotificationDismiss Stream<NotificationData>
no setterinherited
onNotificationTapped Stream<NotificationData>
no setterinherited
onTokenRefresh Stream<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token Future<String?>
no setter

Methods

deleteToken() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited