PushNotificationServiceProviderMixin mixin

Properties

hashCode int
The hash code for this object.
no setterinherited
pushNotifications List<PushNotification>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handlePushNotification(NotificationData data) → void
handlePushNotificationAction(NotificationData data) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(GetIt it) Future<void>
Registers services or dependencies within the provided GetIt instance.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited