PushNotificationsProviders class

Inheritance
Mixed-in types

Constructors

PushNotificationsProviders({required List<PushNotificationProvider> pushNotificationProviders})

Properties

hashCode int
The hash code for this object.
no setterinherited
pushNotificationProviders List<PushNotificationProvider>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
override
listen() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onNotification(Map<String, dynamic> data) → void
override
onNotificationTapped(NotificationData data) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited