ServerNotificationModel class

Annotations
  • @JsonSerializable.new()

Constructors

ServerNotificationModel({required DateTime createdAt, required String uuid, required String code, required String body, required String title, String? senderName, String? senderImage, required String notifiableType, required int notifiableId, required Map<String, dynamic> data, DateTime? readAt, String? authableType, int? authableId})
const
ServerNotificationModel.fromJson(Map<String, dynamic> json)
factory

Properties

authableId int?
final
authableType String?
final
body String
final
code String
final
createdAt DateTime
final
data Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
id int
finalinherited
notifiableId int
final
notifiableType String
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
read bool
no setter
readAt DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderImage String?
final
senderName String?
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
title String
final
uuid String
final

Methods

copyWith({String? uuid, String? notifiableType, int? notifiableId, String? authableType, int? authableId, String? code, String? body, String? title, Map<String, dynamic>? data, String? senderName, String? senderImage, DateTime? readAt, DateTime? createdAt}) ServerNotificationModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the object to a JSON-compatible map.
toJsonString() String
Converts the object to a JSON-formatted string.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited