ServerNotificationsProvider mixin

Superclass constraints
Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
notifications Stream<ServerNotificationData>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unreadNotificationsCount Stream<int>
no setter

Methods

dispose() Future<void>
inherited
listen() → void
inherited
load() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onNotification(Map<String, dynamic> data) → void
inherited
onTap(ServerNotificationModel notification) → void
read(ServerNotificationModel notification) → void
readAll() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited