ChannelableNotification mixin
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createNotification(
dynamic data) → Future< void> - Method to create Notification using CleverTap
-
createNotificationChannel(
{required String channelId, required String channelName, required String channelDescription, required int importance, required bool showBadge, String? sound, String? groupId}) → Future< void> -
createNotificationChannelGroup(
String groupId, String groupName) → Future< void> - Method to create Notification Channel Group
-
deleteNotificationChannel(
String channelId) → Future< void> - Method to delete Notification Channel
-
deleteNotificationChannelGroup(
String groupId) → Future< void> - Method to delete Notification Channel Group
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited