NotificationCenterDataSource class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
loadNotifications(
{String? nextUrl}) → Future< ListResponse< ServerNotificationModel> > -
mapListMResponse<
T extends Model, G extends Jsonable> (Response response) → ListMResponse< T, G> -
inherited
-
mapListResponse<
T extends Model> (Response response) → ListResponse< T> -
inherited
-
mapSingleMResponse<
T extends Model, G extends Jsonable> (Response response) → SingleMResponse< T, G> -
inherited
-
mapSingleResponse<
T extends Model> (Response response) → SingleResponse< T> -
inherited
-
mapSuccessResponse(
Response response) → SuccessResponse -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
String uuid) → Future< void> -
readAll(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited