NotificationCenterProvider class
- Inheritance
-
- Object
- NotificationProvider
- NotificationCenterProvider
- Mixed-in types
Constructors
- NotificationCenterProvider({required PushNotificationProvider pushNotificationProvider, required NotificationCenterDataSource notificationCenterDataSource})
Properties
- currentServerNotificationData ↔ ServerNotificationData?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- notificationCenterDataSource → NotificationCenterDataSource
-
final
-
notifications
→ Stream<
ServerNotificationData> -
no setteroverride
- pushNotificationProvider → PushNotificationProvider
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serverNotificationStreamController
→ StreamController<
ServerNotificationData> -
final
-
unreadNotificationsCount
→ Stream<
int> -
no setteroverride
Methods
-
dispose(
) → Future< void> -
override
-
listen(
) → void -
override
-
load(
{bool reset = false}) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onNotification(
Map< String, dynamic> data) → void -
override
-
onNotificationTapped(
NotificationData data) → void -
inherited
-
onTap(
ServerNotificationModel notification) → void -
override
-
read(
ServerNotificationModel notification) → void -
override
-
readAll(
) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited